# pyglet-particle-system

Particle Effects for Python with Pyglet using a system with Physical Simulation
and 2D Sprites

![preview](pyglet-particles.gif)
An example using the particles

## Dependencies

To use it you need:

- Python v3.7 or above
- pyglet
- numpy


## Usage

Install the package by running: `pip install .` in this directory.

You can see an example in the file **main.py**, and you can run it like this:

`$ python main.py`

